# Utils

Utilities, complementing the Python Standard Library

[https://pypi.org/project/utils-nuuuwan](https://pypi.org/project/utils-nuuuwan)

## Setup & Install

```
pip install utils-nuuuwan
```

## Implementation Details

This library is a aggregation of the following libraries

* [utils_base](https://pypi.org/project/utils_base-nuuuwan/)
* [utils_git](https://pypi.org/project/utils_git-nuuuwan/)
* [utils_twitter](https://pypi.org/project/utils_twitter-nuuuwan/)
* [utils_www](https://pypi.org/project/utils_www-nuuuwan/)

## Version History

### 2.0.4
* Fixed [#5](https://github.com/nuuuwan/utils/issues/5) 

### 2.0.3 (CURRENT)
* Fixed missing mr, hashx, xmlx BUG

### 2.0.2
* Imported _log from utils_base

### 2.0.1 
* Fixed missing requires in setup.py

### 2.0.0
* Base version, ontaining utils_base, utils_git, utils_twitter and utils_www.